==> qtjambi-scxml-6.5.3-sources.jar: io/qt/scxml/QScxmlInvokableServiceFactory.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>Creates invokable service instances</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html">QScxmlInvokableServiceFactory</a></code></p>
 */
public abstract class QScxmlInvokableServiceFactory extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableServiceFactory.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableServiceFactory {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine){
            return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
        }
        @QtUninvokable
        private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
        
    }
    
    
    /**
     * <p>See <code>QScxmlInvokableServiceFactory::<wbr>QScxmlInvokableServiceFactory(QScxmlExecutableContent::InvokeInfo,<wbr>QList&lt;QScxmlExecutableContent::StringId&gt;,<wbr>QList&lt;QScxmlExecutableContent::ParameterInfo&gt;,<wbr>QObject*)</code></p>
     */
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, invokeInfo, names, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableServiceFactory instance, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.@QtPrimitiveType Integer> names, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invokeInfo-prop">QScxmlInvokableServiceFactory::<wbr>invokeInfo()const</a></code></p>
     */
    @QtPropertyReader(name="invokeInfo")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo(){
        return invokeInfo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#names-prop">QScxmlInvokableServiceFactory::<wbr>names()const</a></code></p>
     */
    @QtPropertyReader(name="names")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QList<java.lang.@QtPrimitiveType@NonNull Integer> names(){
        return names_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<java.lang.@QtPrimitiveType Integer> names_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#parameters-prop">QScxmlInvokableServiceFactory::<wbr>parameters()const</a></code></p>
     */
    @QtPropertyReader(name="parameters")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::<wbr>invoke(QScxmlStateMachine*)</a></code></p>
     */
    @QtUninvokable
    public abstract io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine);
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScxmlInvokableServiceFactory(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters) {
        this(invokeInfo, names, parameters, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #invokeInfo()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo getInvokeInfo() {
        return invokeInfo();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #names()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QList<java.lang.@QtPrimitiveType@NonNull Integer> getNames() {
        return names();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #parameters()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> getParameters() {
        return parameters();
    }
}

==> qtjambi-scxml-6.6.2-sources.jar: io/qt/scxml/QScxmlInvokableServiceFactory.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>Creates invokable service instances</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html">QScxmlInvokableServiceFactory</a></code></p>
 */
public abstract class QScxmlInvokableServiceFactory extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableServiceFactory.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableServiceFactory {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine){
            return invoke_native_QScxmlStateMachine_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parentStateMachine));
        }
        @QtUninvokable
        private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
        
    }
    
    
    /**
     * <p>See <code>QScxmlInvokableServiceFactory::<wbr/>QScxmlInvokableServiceFactory(QScxmlExecutableContent::InvokeInfo,<wbr/>QList&lt;QScxmlExecutableContent::StringId&gt;,<wbr/>QList&lt;QScxmlExecutableContent::ParameterInfo&gt;,<wbr/>QObject*)</code></p>
     */
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters, io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, invokeInfo, names, parameters, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableServiceFactory instance, io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo, java.util.Collection<java.lang.@QtPrimitiveType Integer> names, java.util.Collection<? extends io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invokeInfo-prop">QScxmlInvokableServiceFactory::<wbr/>invokeInfo()const</a></code></p>
     */
    @QtPropertyReader(name="invokeInfo")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo(){
        return invokeInfo_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlExecutableContent.InvokeInfo invokeInfo_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#names-prop">QScxmlInvokableServiceFactory::<wbr/>names()const</a></code></p>
     */
    @QtPropertyReader(name="names")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QList<java.lang.@QtPrimitiveType@NonNull Integer> names(){
        return names_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<java.lang.@QtPrimitiveType Integer> names_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#parameters-prop">QScxmlInvokableServiceFactory::<wbr/>parameters()const</a></code></p>
     */
    @QtPropertyReader(name="parameters")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.scxml.QScxmlExecutableContent.ParameterInfo> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservicefactory.html#invoke">QScxmlInvokableServiceFactory::<wbr/>invoke(QScxmlStateMachine*)</a></code></p>
     */
    @QtUninvokable
    public abstract io.qt.scxml.@Nullable QScxmlInvokableService invoke(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine);
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlInvokableService invoke_native_QScxmlStateMachine_ptr(long __this__nativeId, long parentStateMachine);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScxmlInvokableServiceFactory(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded constructor for {@link #QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.InvokeInfo, java.util.Collection, java.util.Collection, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QScxmlInvokableServiceFactory(io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo invokeInfo, java.util.@NonNull Collection<java.lang.@QtPrimitiveType@NonNull Integer> names, java.util.@NonNull Collection<? extends io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> parameters) {
        this(invokeInfo, names, parameters, (io.qt.core.QObject)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #invokeInfo()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.scxml.QScxmlExecutableContent.@NonNull InvokeInfo getInvokeInfo() {
        return invokeInfo();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #names()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QList<java.lang.@QtPrimitiveType@NonNull Integer> getNames() {
        return names();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #parameters()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.scxml.QScxmlExecutableContent.@NonNull ParameterInfo> getParameters() {
        return parameters();
    }
}
